@@ -52,7 +52,9 @@ WINDOW *mainwin;
    keypad(mainwin, TRUE);
    CenterText(1,VERSION);
    CenterText(2,"Ricardo Cerqueira <rmc@ssi.aaum.pt>, 1999");
+#ifdef HAVE_TOUCHWIN
    touchwin(mainwin);
+#endif
    box(mainwin, 0, 0);
    wmove(mainwin,1,1); 
    wprintw(mainwin,"Song Title:");
