@@ -14,7 +14,7 @@
 #include "mp3info.h"
 
 
-void main(int argc, char *argv[]) {
+int main(int argc, char *argv[]) {
 FILE  *fp;
 int c, interactive = 0;
 char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comment[31]="", fbuf[4];
@@ -22,22 +22,22 @@ char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comme
    if (argc < 2 ) /* Only command is given. Short help */ {
 	   printf("%s\r\n  Usage: %s [-h] (-i | -t title -a artist -l album -y year -c comment ) 
 			   /path/to/the/file.mp3\r\n\r\n",VERSION,argv[0]); 
-	   exit();
+	   return 0;
    } else if ( argc != 3 && !strcmp(argv[1],"-i") ) /* Curses mode. Filename missing or garbage */ {
 	   printf("%s\r\nYou must enter an MP3 file as an argument in interactive mode!\r\n  
 			   Usage: %s -i /path/to/the/file.mp3\r\n\r\n",VERSION,argv[0]); 
-	   exit();
+	   return 0;
    }
 
-   if (!strcmp(argv[1],"-h")) { display_help(); exit(); }
+   if (!strcmp(argv[1],"-h")) { display_help(); return 0; }
    if ( !( fp=fopen(argv[argc-1],"rb+") ) ) {
            perror("Error opening MP3");
-           return;
+           return 0;
    }
   
    /* Go to EOF and check if there's already a tag */
 
-   if ( fseek(fp, -128, SEEK_END )) { exit(); }
+   if ( fseek(fp, -128, SEEK_END )) { return 0; }
    fread(fbuf,1,3,fp); fbuf[3] = '\0';
    if (!strcmp("TAG",fbuf)) {
 	   /* Holy cow, Batman! I found something! Better save it for later use... */
@@ -56,11 +56,14 @@ char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comme
    }
   
    /* Let's see what the user wants to do... */
-   while ((c=getopt(argc,argv,"hit:a:l:y:c:"))!=-1) {
+   while ((c=getopt(argc,argv,"vhit:a:l:y:c:"))!=-1) {
 
 	switch(c) {
+		case 'v':
+			view_tag(fp); return 0;
+			break;
 		case 'h':
-			display_help(); exit();
+			display_help(); return 0;
 			break;
 		case 'i':
    	 		tagedit_curs(fp,argv[argc-1],fullline);
@@ -90,6 +93,6 @@ char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comme
    fwrite(fullline,1,128,fp);
 
    fclose(fp);
-   exit();
+   return 0;
 }
 
